Plugin for Martian that uses Aleph as http client
Plugin for Martian that uses Aleph as http client
(aleph-request {:keys [request] :as ctx})Actually performs the HTTP request given the Martian context.
Actually performs the HTTP request given the Martian context.
(as-test-context ctx)Given a Martian context, converts it into a test context that can be used with
the functions as provided by martian.test
Given a Martian context, converts it into a test context that can be used with the functions as provided by `martian.test`
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |